package com.fs.app.controller;


import cn.hutool.core.bean.BeanUtil;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.fs.common.config.FSSysConfig;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.redis.RedisCache;
import com.fs.company.service.ICompanyService;
import com.fs.company.service.ICompanyUserService;
import com.fs.erp.service.IErpOrderService;
import com.fs.pay.pay.domain.OrderCallback;
import com.fs.pay.pay.domain.OrderResult;
import com.fs.pay.pay.dto.OrderQueryDTO;
import com.fs.pay.pay.service.PayService;
import com.fs.pay.pay.util.PayUtil;
import com.fs.pay.service.dto.PayNotifyDTO;
import com.fs.pay.service.dto.RefundNotifyDTO;
import com.fs.pay.service.dto.TradeOrder;
import com.fs.store.domain.FsStorePayment;
import com.fs.store.service.*;
import com.fs.store.vo.PrescribeVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationEventPublisher;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Api("第三方支付接口")
@RestController
@RequestMapping("/app/pay")
public class PayController {

    protected final Logger logger = LoggerFactory.getLogger(BaseController.class);

    @Autowired
    private RedisCache redisCache;
    @Autowired
    private IFsStoreOrderService orderService;
    @Autowired
    private IFsStoreOrderStatusService orderStatusService;
    @Autowired
    private IFsUserBillService billService;
    @Autowired
    private IFsUserService userService;
    @Autowired
    private ApplicationEventPublisher publisher;

    @Autowired
    private FSSysConfig sysConfig;
    @Autowired
    IErpOrderService erpOrderService;

    @Autowired
    private IFsStoreOrderItemService storeOrderItemService;

    @Autowired
    private IFsStorePaymentService storePaymentService;
    @Autowired
    private IFsExpressService expressService;

    @Autowired
    private ICompanyService companyService;

    @Autowired
    PayService ybPayService;

    @Autowired
    private ICompanyUserService companyUserService;

    @ApiOperation("易宝第三方支付回调")
    @PostMapping(value="/ybPayNotify")
    public String ybPayNotify( @RequestBody String jsonBody ) throws Exception {
        //验证
        OrderCallback o= JSONUtil.toBean(jsonBody, OrderCallback.class);
        if(o.getState().equals("0")){
            OrderQueryDTO orderQueryDTO = new OrderQueryDTO();
            orderQueryDTO.setLowOrderId(o.getLowOrderId());
            OrderResult orderResult = ybPayService.getOrder(orderQueryDTO);
            String[] order=o.getLowOrderId().split("-");
            switch (order[0]) {
                case "store":
                    return orderService.payConfirm(1,null,order[1], o.getUpOrderId(),orderResult.getBankTrxId(),orderResult.getBankOrderId());
                case "store_remain":
                    return orderService.payRemainConfirm( order[1], o.getUpOrderId(),orderResult.getBankTrxId(),orderResult.getBankOrderId());
                case "payment":
                    return storePaymentService.payConfirm(order[1],o.getUpOrderId(),orderResult.getBankTrxId(),orderResult.getBankOrderId());
            }
        }
        return "";

    }



    @ApiOperation("小雨点第三方支付回调")
    @PostMapping(value="/payNotify")
    public String payNotify(HttpServletRequest request,PayNotifyDTO dto) throws Exception {
            if("SUCCESS".equals(dto.getOrderStatus())) {
                //订单号
                String tradeNo = dto.getMerchOrderNo();
                List<TradeOrder> tradeOrders= JSON.parseArray(dto.getTradeOrders(),TradeOrder.class);
                if(tradeOrders!=null&&tradeOrders.size()>0){
                    for(TradeOrder tradeOrder:tradeOrders){
                        String[] order=tradeOrder.getSubMerchOrderNo().split("-");
                        switch (order[0]) {
                            case "store":
                                orderService.payConfirm(1,null,order[1], tradeNo,dto.getBankTransactionId(),dto.getBankSerialNo());
                                return "success";
                            case "store_remain":
                                orderService.payRemainConfirm( order[1], tradeNo,dto.getBankTransactionId(),dto.getBankSerialNo());
                                return "success";
                            case "payment":
                                return storePaymentService.payConfirm(order[1], tradeNo,dto.getBankTransactionId(),dto.getBankSerialNo());
                        }
                    }
                }
            }
            return "success";
    }

    @ApiOperation("小雨点第三方退款回调")
    @PostMapping(value="/refundNotify")
    public String refundNotify(HttpServletRequest request, RefundNotifyDTO dto) throws Exception {
        if("SUCCESS".equals(dto.getOrderStatus())) {
            String[] orderIds=dto.getOrigMerchOrderNo().split("-");
            FsStorePayment storePayment=null;
            switch (orderIds[0]) {
                case "store":
                    storePayment=storePaymentService.selectFsStorePaymentByCode(orderIds[1]);
                    if(storePayment!=null){
                        storePayment.setRefundMoney(BigDecimal.valueOf(Double.parseDouble(dto.getAmount())));
                        storePayment.setStatus(-1);
                        storePayment.setRefundTime(new Date());
                        storePaymentService.updateFsStorePayment(storePayment);
                    }
                    return "success";
                case "store_remain":
                    storePayment=storePaymentService.selectFsStorePaymentByCode(orderIds[1]);
                    if(storePayment!=null){
                        storePayment.setRefundMoney(BigDecimal.valueOf(Double.parseDouble(dto.getAmount())));
                        storePayment.setStatus(-1);
                        storePayment.setRefundTime(new Date());
                        storePaymentService.updateFsStorePayment(storePayment);
                    }
                    return "success";
                case "doctor":
                   return "success";
                case "payment":
                    storePaymentService.refund(orderIds[1]);
                    return "success";
            }
            return "success";
        }
        return "success";
    }


//    @Transactional
//    public String paymentOp(String payCode,String tradeNo,String bankTransactionId,String bankSerialNo) {
//
//        //更新订单状态
//        FsStorePayment storePayment=storePaymentService.selectFsStorePaymentByCode(payCode);
//        if(!storePayment.getStatus().equals(0)){
//            return "";
//        }
//        storePayment.setStatus(1);
//        storePayment.setPayTime(new Date());
//        storePayment.setTradeNo(tradeNo);
//        storePayment.setBankSerialNo(bankSerialNo);
//        storePayment.setBankTransactionId(bankTransactionId);
//        storePaymentService.updateFsStorePayment(storePayment);
//        //增加佣金
//        if(storePayment.getCompanyId()!=null&&storePayment.getCompanyId()>0){
//            companyService.addCompanyPaymentMoney(storePayment);
//        }
//        return "success";
//
//    }


}
