package com.fs.ad.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.ad.mapper.AdDomainMapper;
import com.fs.ad.domain.AdDomain;
import com.fs.ad.service.IAdDomainService;

/**
 * 广告域名Service业务层处理
 * 
 * @author fs
 * @date 2025-03-04
 */
@Service
public class AdDomainServiceImpl extends ServiceImpl<AdDomainMapper, AdDomain> implements IAdDomainService {

    /**
     * 查询广告域名
     * 
     * @param id 广告域名主键
     * @return 广告域名
     */
    @Override
    public AdDomain selectAdDomainById(Long id)
    {
        return baseMapper.selectAdDomainById(id);
    }

    /**
     * 查询广告域名列表
     * 
     * @param adDomain 广告域名
     * @return 广告域名
     */
    @Override
    public List<AdDomain> selectAdDomainList(AdDomain adDomain)
    {
        return baseMapper.selectAdDomainList(adDomain);
    }

    /**
     * 新增广告域名
     * 
     * @param adDomain 广告域名
     * @return 结果
     */
    @Override
    public int insertAdDomain(AdDomain adDomain)
    {
        adDomain.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertAdDomain(adDomain);
    }

    /**
     * 修改广告域名
     * 
     * @param adDomain 广告域名
     * @return 结果
     */
    @Override
    public int updateAdDomain(AdDomain adDomain)
    {
        adDomain.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateAdDomain(adDomain);
    }

    /**
     * 批量删除广告域名
     * 
     * @param ids 需要删除的广告域名主键
     * @return 结果
     */
    @Override
    public int deleteAdDomainByIds(Long[] ids)
    {
        return baseMapper.deleteAdDomainByIds(ids);
    }

    /**
     * 删除广告域名信息
     * 
     * @param id 广告域名主键
     * @return 结果
     */
    @Override
    public int deleteAdDomainById(Long id)
    {
        return baseMapper.deleteAdDomainById(id);
    }
}
