package com.fs.bdAdv.service.impl;

import com.fs.bdAdv.domain.FsAdvSem;
import com.fs.bdAdv.mapper.FsAdvSemMapper;
import com.fs.bdAdv.param.FsAdvSemStatisticsByDayParam;
import com.fs.bdAdv.service.IFsAdvSemService;
import com.fs.bdAdv.vo.FsAdvSemStatisticsByDayVo;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * App广告投流Service业务层处理
 *
 * @author fs
 * @date 2024-11-19
 */
@Service
public class FsAdvSemServiceImpl implements IFsAdvSemService
{
    @Autowired
    private FsAdvSemMapper fsAdvSemMapper;

    /**
     * 查询App广告投流
     *
     * @param id App广告投流主键
     * @return App广告投流
     */
    @Override
    public FsAdvSem selectFsAdvSemById(Long id)
    {
        return fsAdvSemMapper.selectFsAdvSemById(id);
    }

    /**
     * 查询App广告投流列表
     *
     * @param fsAdvSem App广告投流
     * @return App广告投流
     */
    @Override
    public List<FsAdvSem> selectFsAdvSemList(FsAdvSem fsAdvSem)
    {
        return fsAdvSemMapper.selectFsAdvSemList(fsAdvSem);
    }

    /**
     * 新增App广告投流
     *
     * @param fsAdvSem App广告投流
     * @return 结果
     */
    @Override
    public int insertFsAdvSem(FsAdvSem fsAdvSem)
    {
        fsAdvSem.setCreateTime(DateUtils.getNowDate());
        return fsAdvSemMapper.insertFsAdvSem(fsAdvSem);
    }

    /**
     * 修改App广告投流
     *
     * @param fsAdvSem App广告投流
     * @return 结果
     */
    @Override
    public int updateFsAdvSem(FsAdvSem fsAdvSem)
    {
        fsAdvSem.setUpdateTime(DateUtils.getNowDate());
        return fsAdvSemMapper.updateFsAdvSem(fsAdvSem);
    }

    /**
     * 批量删除App广告投流
     *
     * @param ids 需要删除的App广告投流主键
     * @return 结果
     */
    @Override
    public int deleteFsAdvSemByIds(Long[] ids)
    {
        return fsAdvSemMapper.deleteFsAdvSemByIds(ids);
    }

    /**
     * 删除App广告投流信息
     *
     * @param id App广告投流主键
     * @return 结果
     */
    @Override
    public int deleteFsAdvSemById(Long id)
    {
        return fsAdvSemMapper.deleteFsAdvSemById(id);
    }

    @Override
    public FsAdvSem selectFsAdvSemByOaid(String oaid) {
        return fsAdvSemMapper.selectFsAdvSemByOaid(oaid);
    }

    @Override
    public FsAdvSem selectFsAdvSemByModel(String model, Integer osType) {
        return fsAdvSemMapper.selectFsAdvSemByModel(model,osType);
    }

    @Override
    public List<FsAdvSemStatisticsByDayVo> selectFsAdvSemStatisticsByDayVo(FsAdvSemStatisticsByDayParam param) {
        return fsAdvSemMapper.selectFsAdvSemStatisticsByDayVo(param);
    }


}
