package com.fs.chat.service;

import com.fs.chat.domain.ChatDatasetFile;
import com.fs.chat.dto.ChatDatasetFileExportDTO;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;

/**
 * 文件Service接口
 *
 * @author fs
 * @date 2024-04-21
 */
public interface IChatDatasetFileService
{
    /**
     * 查询文件
     *
     * @param fileId 文件主键
     * @return 文件
     */
    public ChatDatasetFile selectChatDatasetFileByFileId(Long fileId);

    /**
     * 查询文件列表
     *
     * @param chatDatasetFile 文件
     * @return 文件集合
     */
    public List<ChatDatasetFile> selectChatDatasetFileList(ChatDatasetFile chatDatasetFile);

    /**
     * 新增文件
     *
     * @param chatDatasetFile 文件
     * @return 结果
     */
    public int insertChatDatasetFile(ChatDatasetFile chatDatasetFile);

    /**
     * 修改文件
     *
     * @param chatDatasetFile 文件
     * @return 结果
     */
    public int updateChatDatasetFile(ChatDatasetFile chatDatasetFile);

    /**
     * 批量删除文件
     *
     * @param fileIds 需要删除的文件主键集合
     * @return 结果
     */
    public int deleteChatDatasetFileByFileIds(Long[] fileIds);

    /**
     * 删除文件信息
     *
     * @param fileId 文件主键
     * @return 结果
     */
    public int deleteChatDatasetFileByFileId(Long fileId);


    MultipartFile convertChatDatasetFileByExcel(List<ChatDatasetFileExportDTO> list,String fileName) throws IOException;

}
