package com.fs.fastGpt.service.impl;

import com.fs.fastGpt.domain.FastGptRoleTag;
import com.fs.fastGpt.mapper.FastGptRoleTagMapper;
import com.fs.fastGpt.service.IFastGptRoleTagService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * AI的标签Service业务层处理
 *
 * @author fs
 * @date 2024-11-04
 */
@Service
public class FastGptRoleTagServiceImpl implements IFastGptRoleTagService
{
    @Autowired
    private FastGptRoleTagMapper fastGptRoleTagMapper;

    /**
     * 查询AI的标签
     *
     * @param id AI的标签主键
     * @return AI的标签
     */
    @Override
    public FastGptRoleTag selectFastGptRoleTagById(Long id)
    {
        return fastGptRoleTagMapper.selectFastGptRoleTagById(id);
    }

    /**
     * 查询AI的标签列表
     *
     * @param fastGptRoleTag AI的标签
     * @return AI的标签
     */
    @Override
    public List<FastGptRoleTag> selectFastGptRoleTagList(FastGptRoleTag fastGptRoleTag)
    {
        return fastGptRoleTagMapper.selectFastGptRoleTagList(fastGptRoleTag);
    }

    @Override
    public List<FastGptRoleTag> selectFastGptRoleTagListByRoleId(Long roleId) {
        return fastGptRoleTagMapper.selectFastGptRoleTagListByRoleId(roleId);
    }

    /**
     * 新增AI的标签
     *
     * @param fastGptRoleTag AI的标签
     * @return 结果
     */
    @Override
    public int insertFastGptRoleTag(FastGptRoleTag fastGptRoleTag)
    {
        return fastGptRoleTagMapper.insertFastGptRoleTag(fastGptRoleTag);
    }

    /**
     * 修改AI的标签
     *
     * @param fastGptRoleTag AI的标签
     * @return 结果
     */
    @Override
    public int updateFastGptRoleTag(FastGptRoleTag fastGptRoleTag)
    {
        return fastGptRoleTagMapper.updateFastGptRoleTag(fastGptRoleTag);
    }

    /**
     * 批量删除AI的标签
     *
     * @param ids 需要删除的AI的标签主键
     * @return 结果
     */
    @Override
    public int deleteFastGptRoleTagByIds(Long[] ids)
    {
        return fastGptRoleTagMapper.deleteFastGptRoleTagByIds(ids);
    }

    /**
     * 删除AI的标签信息
     *
     * @param id AI的标签主键
     * @return 结果
     */
    @Override
    public int deleteFastGptRoleTagById(Long id)
    {
        return fastGptRoleTagMapper.deleteFastGptRoleTagById(id);
    }
}
