package com.fs.store.service;

import com.fs.common.core.domain.R;
import com.fs.store.domain.FsIntegralOrder;
import com.fs.store.param.FsIntegralOrderCreateParam;
import com.fs.store.param.FsIntegralOrderListUParam;
import com.fs.store.param.FsIntegralOrderParam;
import com.fs.store.vo.FsIntegralOrderListUVO;
import com.fs.store.vo.FsIntegralOrderListVO;
import com.fs.store.vo.FsIntegralOrderPVO;
import com.fs.store.vo.FsStoreProductDeliverExcelVO;

import java.util.List;

/**
 * 积分商品订单Service接口
 *
 * @author fs
 * @date 2023-11-02
 */
public interface IFsIntegralOrderService
{
    /**
     * 查询积分商品订单
     *
     * @param orderId 积分商品订单主键
     * @return 积分商品订单
     */
    public FsIntegralOrder selectFsIntegralOrderByOrderId(Long orderId);

    /**
     * 查询积分商品订单列表
     *
     * @param fsIntegralOrder 积分商品订单
     * @return 积分商品订单集合
     */
    public List<FsIntegralOrder> selectFsIntegralOrderList(FsIntegralOrder fsIntegralOrder);

    /**
     * 新增积分商品订单
     *
     * @param fsIntegralOrder 积分商品订单
     * @return 结果
     */
    public int insertFsIntegralOrder(FsIntegralOrder fsIntegralOrder);

    /**
     * 修改积分商品订单
     *
     * @param fsIntegralOrder 积分商品订单
     * @return 结果
     */
    public int updateFsIntegralOrder(FsIntegralOrder fsIntegralOrder);

    /**
     * 批量删除积分商品订单
     *
     * @param orderIds 需要删除的积分商品订单主键集合
     * @return 结果
     */
    public int deleteFsIntegralOrderByOrderIds(Long[] orderIds);

    /**
     * 删除积分商品订单信息
     *
     * @param orderId 积分商品订单主键
     * @return 结果
     */
    public int deleteFsIntegralOrderByOrderId(Long orderId);

    List<FsIntegralOrderListVO> selectFsIntegralOrderListVO(FsIntegralOrderParam fsIntegralOrder);

    int sendGoods(FsIntegralOrder fsIntegralOrder);

    List<FsIntegralOrderListUVO> selectFsIntegralOrderListUVO(FsIntegralOrderListUParam param);

    R createOrder(FsIntegralOrderCreateParam param);

    String importProductDeliver(List<FsStoreProductDeliverExcelVO> list);

    FsIntegralOrderPVO selectFsIntegralOrderPVO(Long orderId);
}
