package com.fs.store.service;

import java.util.List;

import com.fs.common.core.domain.R;
import com.fs.store.domain.FsStoreCouponIssue;
import com.fs.store.param.FsCouponIssueParam;
import com.fs.store.param.FsStoreCouponReceiveParam;
import com.fs.store.vo.FsStoreCouponIssueVO;

/**
 * 优惠券领取Service接口
 * 
 * @author fs
 * @date 2022-03-15
 */
public interface IFsStoreCouponIssueService 
{
    /**
     * 查询优惠券领取
     * 
     * @param id 优惠券领取ID
     * @return 优惠券领取
     */
    public FsStoreCouponIssue selectFsStoreCouponIssueById(Long id);

    /**
     * 查询优惠券领取列表
     * 
     * @param fsStoreCouponIssue 优惠券领取
     * @return 优惠券领取集合
     */
    public List<FsStoreCouponIssue> selectFsStoreCouponIssueList(FsStoreCouponIssue fsStoreCouponIssue);

    /**
     * 新增优惠券领取
     * 
     * @param fsStoreCouponIssue 优惠券领取
     * @return 结果
     */
    public int insertFsStoreCouponIssue(FsStoreCouponIssue fsStoreCouponIssue);

    /**
     * 修改优惠券领取
     * 
     * @param fsStoreCouponIssue 优惠券领取
     * @return 结果
     */
    public int updateFsStoreCouponIssue(FsStoreCouponIssue fsStoreCouponIssue);

    /**
     * 批量删除优惠券领取
     * 
     * @param ids 需要删除的优惠券领取ID
     * @return 结果
     */
    public int deleteFsStoreCouponIssueByIds(Long[] ids);

    /**
     * 删除优惠券领取信息
     * 
     * @param id 优惠券领取ID
     * @return 结果
     */
    public int deleteFsStoreCouponIssueById(Long id);

    List<FsStoreCouponIssueVO> selectFsStoreCouponIssueListQueryVO(String userId, FsStoreCouponIssue map);

    R receive(String userId, FsStoreCouponReceiveParam param);

    List<FsStoreCouponIssueVO> getCompanyCouponIssueList(FsCouponIssueParam map);

    FsStoreCouponIssueVO selectFsStoreCouponIssueVOById(Long id);

    List<FsStoreCouponIssueVO> selectFsStoreCouponIssueListVO(FsStoreCouponIssue fsStoreCouponIssue);
}
