package com.fs.store.service;

import java.util.List;
import java.util.Map;

import com.alibaba.fastjson.JSONObject;
import com.fs.common.core.domain.R;
import com.fs.store.domain.FsStorePayment;
import com.fs.store.param.FsStorePaymentPayParam;
import com.fs.store.param.FsStorePaymentParam;
import com.fs.store.param.FsStoreStatisticsParam;
import com.fs.his.param.WxSendRedPacketParam;
import com.fs.store.vo.FsStorePaymentStatisticsVO;
import com.fs.store.vo.FsStorePaymentVO;

/**
 * 支付明细Service接口
 *
 * @author fs
 * @date 2022-06-20
 */
public interface IFsStorePaymentService
{
    /**
     * 查询支付明细
     *
     * @param paymentId 支付明细ID
     * @return 支付明细
     */
    public FsStorePayment selectFsStorePaymentById(Long paymentId);

    /**
     * 查询支付明细列表
     *
     * @param fsStorePayment 支付明细
     * @return 支付明细集合
     */
    public List<FsStorePayment> selectFsStorePaymentList(FsStorePayment fsStorePayment);

    /**
     * 新增支付明细
     *
     * @param fsStorePayment 支付明细
     * @return 结果
     */
    public int insertFsStorePayment(FsStorePayment fsStorePayment);

    /**
     * 修改支付明细
     *
     * @param fsStorePayment 支付明细
     * @return 结果
     */
    public int updateFsStorePayment(FsStorePayment fsStorePayment);

    /**
     * 批量删除支付明细
     *
     * @param paymentIds 需要删除的支付明细ID
     * @return 结果
     */
    public int deleteFsStorePaymentByIds(Long[] paymentIds);

    /**
     * 删除支付明细信息
     *
     * @param paymentId 支付明细ID
     * @return 结果
     */
    public int deleteFsStorePaymentById(Long paymentId);

    R payment(FsStorePaymentPayParam payment);

    FsStorePayment selectFsStorePaymentByCode(String payCode);

    List<FsStorePaymentVO> selectFsStorePaymentListQuery(FsStorePaymentParam fsStorePayment);

    List<FsStorePaymentVO> exportFsStorePaymentList(FsStorePaymentParam fsStorePayment);


    List<FsStorePaymentVO> selectFsStorePaymentListQueryVO(FsStorePaymentParam fsStorePayment);

    List<FsStorePaymentVO> selectFsMyStorePaymentListQueryVO(FsStorePaymentParam fsStorePayment);


    List<FsStorePayment> selectFsStorePaymentByOrderId(Long orderId);

    Long selectFsStorePaymentCount(int type,Long companyId);

    String payConfirm(String payCode,String tradeNo,String bankTransactionId,String bankSerialNo);

    String refund(String orderCode);

    List<JSONObject> selectFsStorePaymentCounts(Map<String, Object> toMap);

    List<FsStorePaymentStatisticsVO> selectFsStorePaymentStatisticsList(FsStoreStatisticsParam param);

    List<FsStorePayment> selectFsStorePaymentByOrder(Long orderId);

    FsStorePayment selectFsStorePaymentByTradeNo(String tradeNo);

    R sendRedPacket(WxSendRedPacketParam param);
}
