package com.fs.store.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.store.mapper.FsAppVersionMapper;
import com.fs.store.domain.FsAppVersion;
import com.fs.store.service.IFsAppVersionService;

/**
 * 安卓版本Service业务层处理
 *
 * @author fs
 * @date 2023-02-03
 */
@Service
public class FsAppVersionServiceImpl implements IFsAppVersionService
{
    @Autowired
    private FsAppVersionMapper fsAppVersionMapper;

    /**
     * 查询安卓版本
     *
     * @param versionId 安卓版本ID
     * @return 安卓版本
     */
    @Override
    public FsAppVersion selectFsAppVersionById(Long versionId)
    {
        return fsAppVersionMapper.selectFsAppVersionById(versionId);
    }

    /**
     * 查询安卓版本列表
     *
     * @param fsAppVersion 安卓版本
     * @return 安卓版本
     */
    @Override
    public List<FsAppVersion> selectFsAppVersionList(FsAppVersion fsAppVersion)
    {
        return fsAppVersionMapper.selectFsAppVersionList(fsAppVersion);
    }

    /**
     * 新增安卓版本
     *
     * @param fsAppVersion 安卓版本
     * @return 结果
     */
    @Override
    public int insertFsAppVersion(FsAppVersion fsAppVersion)
    {
        fsAppVersion.setCreateTime(DateUtils.getNowDate());
        return fsAppVersionMapper.insertFsAppVersion(fsAppVersion);
    }

    /**
     * 修改安卓版本
     *
     * @param fsAppVersion 安卓版本
     * @return 结果
     */
    @Override
    public int updateFsAppVersion(FsAppVersion fsAppVersion)
    {
        return fsAppVersionMapper.updateFsAppVersion(fsAppVersion);
    }

    /**
     * 批量删除安卓版本
     *
     * @param versionIds 需要删除的安卓版本ID
     * @return 结果
     */
    @Override
    public int deleteFsAppVersionByIds(Long[] versionIds)
    {
        return fsAppVersionMapper.deleteFsAppVersionByIds(versionIds);
    }

    /**
     * 删除安卓版本信息
     *
     * @param versionId 安卓版本ID
     * @return 结果
     */
    @Override
    public int deleteFsAppVersionById(Long versionId)
    {
        return fsAppVersionMapper.deleteFsAppVersionById(versionId);
    }

    @Override
    public FsAppVersion getAppVersion(String type) {
        return fsAppVersionMapper.getAppVersion(type);
    }

    @Override
    public FsAppVersion getNewVersion(Integer appType, int i) {
        return null;
    }
}
