package com.fs.store.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.store.mapper.FsStoreOrderOfflineItemMapper;
import com.fs.store.domain.FsStoreOrderOfflineItem;
import com.fs.store.service.IFsStoreOrderOfflineItemService;

/**
 * 线下订单详情Service业务层处理
 *
 * @author fs
 * @date 2024-10-29
 */
@Service
public class FsStoreOrderOfflineItemServiceImpl implements IFsStoreOrderOfflineItemService
{
    @Autowired
    private FsStoreOrderOfflineItemMapper fsStoreOrderOfflineItemMapper;

    /**
     * 查询线下订单详情
     *
     * @param itemId 线下订单详情ID
     * @return 线下订单详情
     */
    @Override
    public FsStoreOrderOfflineItem selectFsStoreOrderOfflineItemById(Long itemId)
    {
        return fsStoreOrderOfflineItemMapper.selectFsStoreOrderOfflineItemById(itemId);
    }

    /**
     * 查询线下订单详情列表
     *
     * @param fsStoreOrderOfflineItem 线下订单详情
     * @return 线下订单详情
     */
    @Override
    public List<FsStoreOrderOfflineItem> selectFsStoreOrderOfflineItemList(FsStoreOrderOfflineItem fsStoreOrderOfflineItem)
    {
        return fsStoreOrderOfflineItemMapper.selectFsStoreOrderOfflineItemList(fsStoreOrderOfflineItem);
    }

    /**
     * 新增线下订单详情
     *
     * @param fsStoreOrderOfflineItem 线下订单详情
     * @return 结果
     */
    @Override
    public int insertFsStoreOrderOfflineItem(FsStoreOrderOfflineItem fsStoreOrderOfflineItem)
    {
        return fsStoreOrderOfflineItemMapper.insertFsStoreOrderOfflineItem(fsStoreOrderOfflineItem);
    }

    /**
     * 修改线下订单详情
     *
     * @param fsStoreOrderOfflineItem 线下订单详情
     * @return 结果
     */
    @Override
    public int updateFsStoreOrderOfflineItem(FsStoreOrderOfflineItem fsStoreOrderOfflineItem)
    {
        return fsStoreOrderOfflineItemMapper.updateFsStoreOrderOfflineItem(fsStoreOrderOfflineItem);
    }

    /**
     * 批量删除线下订单详情
     *
     * @param itemIds 需要删除的线下订单详情ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreOrderOfflineItemByIds(Long[] itemIds)
    {
        return fsStoreOrderOfflineItemMapper.deleteFsStoreOrderOfflineItemByIds(itemIds);
    }

    /**
     * 删除线下订单详情信息
     *
     * @param itemId 线下订单详情ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreOrderOfflineItemById(Long itemId)
    {
        return fsStoreOrderOfflineItemMapper.deleteFsStoreOrderOfflineItemById(itemId);
    }
}
