package com.fs.store.service.impl;


import com.fasterxml.jackson.databind.ObjectMapper;
import com.fs.common.utils.DateUtils;
import com.fs.store.domain.FsTestTemp;
import com.fs.store.mapper.FsTestTempMapper;
import com.fs.store.service.IFsTestTempService;
import com.fs.his.vo.OptionsVO;;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 测一测模板Service业务层处理
 *
 * @author fs
 * @date 2023-09-04
 */
@Service
public class FsTestTempServiceImpl implements IFsTestTempService
{
    @Autowired
    private FsTestTempMapper fsTestTempMapper;

    /**
     * 查询测一测模板
     *
     * @param tempId 测一测模板主键
     * @return 测一测模板
     */
    @Override
    public FsTestTemp selectFsTestTempByTempId(Long tempId)
    {
        return fsTestTempMapper.selectFsTestTempByTempId(tempId);
    }

    /**
     * 查询测一测模板列表
     *
     * @param fsTestTemp 测一测模板
     * @return 测一测模板
     */
    @Override
    public List<FsTestTemp> selectFsTestTempList(FsTestTemp fsTestTemp)
    {
        return fsTestTempMapper.selectFsTestTempList(fsTestTemp);
    }

    /**
     * 新增测一测模板
     *
     * @param fsTestTemp 测一测模板
     * @return 结果
     */
    @Override
    public int insertFsTestTemp(FsTestTemp fsTestTemp)
    {
        fsTestTemp.setCreateTime(DateUtils.getNowDate());
        return fsTestTempMapper.insertFsTestTemp(fsTestTemp);
    }



    /**
     * 修改测一测模板
     *
     * @param fsTestTemp 测一测模板
     * @return 结果
     */
    @Override
    public int updateFsTestTemp(FsTestTemp fsTestTemp)
    {
        fsTestTemp.setUpdateTime(DateUtils.getNowDate());
        return fsTestTempMapper.updateFsTestTemp(fsTestTemp);
    }

    /**
     * 批量删除测一测模板
     *
     * @param tempIds 需要删除的测一测模板主键
     * @return 结果
     */
    @Override
    public int deleteFsTestTempByTempIds(Long[] tempIds)
    {
        return fsTestTempMapper.deleteFsTestTempByTempIds(tempIds);
    }

    /**
     * 删除测一测模板信息
     *
     * @param tempId 测一测模板主键
     * @return 结果
     */
    @Override
    public int deleteFsTestTempByTempId(Long tempId)
    {
        return fsTestTempMapper.deleteFsTestTempByTempId(tempId);
    }

    @Override
    public List<OptionsVO> selectAllTestTempList() {
        return fsTestTempMapper.selectAllTestTempList();
    }

    @Override
    public List<String> selectFsTempTypeByTempId(Long tempId) {
        FsTestTemp fsTestTemp = fsTestTempMapper.selectFsTestTempByTempId(tempId);
        if (fsTestTemp==null){
            return null;
        }
        String itemTypeJson = fsTestTemp.getItemTypeJson();
        ArrayList<String> list = new ArrayList<>();
        ObjectMapper objectMapper = new ObjectMapper();
        try {
            List<Map<String, Object>> data = objectMapper.readValue(itemTypeJson,ArrayList.class);
            for (Map<String, Object> d : data) {
                String itemType = (String) d.get("itemType");
                list.add(itemType);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return list;
    }
}
